Overview
========

.. image:: https://zenodo.org/badge/582657662.svg
  :target: https://doi.org/10.5281/zenodo.15184988


wnnet is a python package for handling
`webnucleo <http://webnucleo.org/>`_ reaction networks.

|pypi| |doc_stat| |license| |test| |lint-test| |black|

Installation
------------

Install from `PyPI <https://pypi.org/project/wnnet>`_ with pip by
typing in your favorite terminal::

    $ pip install wnnet

Authors
-------

- Bradley S. Meyer <mbradle@g.clemson.edu>
- Mengke Li <mengkel@g.clemson.edu>

Contribute
----------

- Issue Tracker: `<https://github.com/mbradle/wnnet/issues/>`_
- Source Code: `<https://github.com/mbradle/wnnet/>`_

License
-------

The project is licensed under the GNU Public License v3 (or later).

Documentation
-------------

The project documentation is available at `<https://wnnet.readthedocs.io>`_.

Usage
-----

The best way to get started using wnnet is to follow the
`tutorial <https://github.com/mbradle/wnnet/tree/main/tutorial>`_.

.. |pypi| image:: https://badge.fury.io/py/wnnet.svg 
    :target: https://badge.fury.io/py/wnnet
.. |license| image:: https://img.shields.io/github/license/mbradle/wnnet
    :alt: GitHub
.. |doc_stat| image:: https://readthedocs.org/projects/wnnet/badge/?version=latest 
    :target: https://wnnet.readthedocs.io/en/latest/?badge=latest 
    :alt: Documentation Status
.. |test| image:: https://github.com/mbradle/wnnet/actions/workflows/test.yml/badge.svg?branch=main&event=push
        :target: https://github.com/mbradle/wnnet/actions/workflows/test.yml
.. |lint| image:: https://img.shields.io/badge/linting-pylint-yellowgreen
    :target: https://github.com/pylint-dev/pylint
.. |lint-test| image:: https://github.com/mbradle/wnnet/actions/workflows/lint.yml/badge.svg?branch=main&event=push
        :target: https://github.com/mbradle/wnnet/actions/workflows/lint.yml
.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
